@@ -669,14 +669,16 @@
             this._on({
                 "click li a": function(event) {
                     var $item = $(event.currentTarget).closest("li"),
-                        model = $item.data("model");
+                        $playlist = $item.closest(".ui-collapsible"),
+                        tracks = $playlist.data("model").tracks,
+                        index = $item.index();
                     $.mopidy.connect().then(function() {
                         var tracklist = this.tracklist,
                             playback = this.playback;
-                        tracklist.add(null, null, model.uri).then(function(tlTracks) {
-                            if (tlTracks && tlTracks.length) {
-                                playback.play(tlTracks[0]);
-                            }
+                        tracklist.clear().then(function() {
+                            tracklist.add(tracks).then(function(tlTracks) {
+                                playback.play(tlTracks[index]);
+                            });
                         });
                     });
                     event.preventDefault();
